darkhistory.spec.transferfunclist — DarkHistory documentation

# darkhistory.spec.transferfunclist

Functions and classes for processing lists of transfer functions.

Classes

`TransferFuncInterp`(tflistarrs[, rs_nodes, …]) | Interpolation function over list of TransferFuncList objects.
`TransferFuncInterps`(tfInterps, xe_arr) | Interpolation function over list of TransferFuncList objects.
`TransferFuncList`(tflist) | List of transfer functions.
`TransferFuncListArray`(tflist_arr, x_arr) | Array of TransferFuncList for array of xH, xHe values.

#### Previous topic

darkhistory.spec.spectrum.Spectrum

#### Next topic

darkhistory.spec.transferfunclist.TransferFuncInterp

### This Page

Show Source